#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# vim: fenc=utf-8
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
#
#

"""
File name: constants.py
Author: dhilipsiva <dhilipsiva@gmail.com>
Date created: 2016-11-07
"""

RISK_ENUM_UNKNOWN = -1
RISK_ENUM_NONE = 0
RISK_ENUM_LOW = 1
RISK_ENUM_MEDIUM = 2
RISK_ENUM_HIGH = 3
